@@ -1,8 +1,6 @@
 #' Extract important model attributes
 #' @description Provides a convenient way to extract any kind of model information from
 #' common model objects
-#' @importFrom stats coef residuals AIC
-#' @importFrom lme4 lmer
 #' @param model_object A model object for example a linear model object, generalized linear model object,
 #' analysis of variance object.
 #' @param what character. The attribute you would like to obtain for instance p_value
@@ -41,13 +39,13 @@ predictor_var <- formula_build[2]
 response_var <- formula_build[1]
 model_summary <- summary(model_object)
 model_attrs_list <- list(call=model_call,
-                         aic = AIC(model_object,...), bic = stats::BIC(model_object,...),
-                       log_lik= stats::logLik(model_object,...),
-                       deviance = stats::deviance(model_object,...),
-                       df.resid= stats::df.residual(model_object,...),
-                      coeffs = stats::coef(model_object,...) , predictors = predictor_var,
-                      residuals = stats::residuals(model_object,...),
-                      resids = stats::residuals(model_object,...),
+                         aic = AIC(model_object,...), bic = BIC(model_object,...),
+                       log_lik= logLik(model_object,...),
+                       deviance = deviance(model_object,...),
+                       df.resid= df.residual(model_object,...),
+                      coeffs = coef(model_object,...) , predictors = predictor_var,
+                      residuals = residuals(model_object,...),
+                      resids = residuals(model_object,...),
                            response = response_var,
                       r2 = model_summary$r.squared,
                       adj_r2 = model_summary$adj.r.squared,
@@ -117,7 +115,7 @@ if(any(! what %in% possible_what)) stop(paste0(c("what should be one of",possibl
 model_attrs_list <-list(fixed_effects = model_summary[[10]],
                         resids = model_summary [[16]],
          residuals= residuals(model_summary),
-         log_lik = stats::logLik(model_object,...),
+         log_lik = logLik(model_object,...),
          random_groups = model_summary [[9]],
          random_effects = Filter(Negate(anyNA),as.data.frame(model_summary[[13]])),
          reml = model_summary [[14]],formula = model_summary[[15]],
