@@ -10,12 +10,6 @@
 #' @param control See caret ?trainControl for details.
 #' @param new_data A data set to validate the model or for which predictions are required
 #' @param ... Other arguments to caret's train function
-#' @importFrom dplyr "%>%"
-#' @importFrom stats "as.formula"  "complete.cases" "setNames" "na.omit" "predict"
-#' @importFrom dplyr "arrange" "desc"
-#' @import caret
-#' @import e1071
-#' @rawNamespace   import(Metrics,except=c("precision","recall"))
 #' @return A list containing two objects. A tibble containing a summary of the metrics per model,
 #' a tibble containing predicted values and information concerning the model
 #' @details Most of the details of the parameters can be found in the caret package documentation.
@@ -27,10 +21,10 @@
 #' Kuhn (2008), "Building Predictive Models in R Using the caret" (http://www.jstatsoft.org/article/view/v028i05/v28i05.pold_data)
 #' @examples
 #' data("yields", package="manymodelr")
-#' train_set<-createDataPartition(yields$normal,p=0.8,list=FALSE)
+#' train_set<-caret::createDataPartition(yields$normal,p=0.8,list=FALSE)
 #' valid_set<-yields[-train_set,]
 #' train_set<-yields[train_set,]
-#' ctrl<-trainControl(method="cv",number=5)
+#' ctrl<-caret::trainControl(method="cv",number=5)
 #' set.seed(233)
 #' m<-multi_model_1(train_set,"normal",".",c("knn","rpart"),
 #' "Accuracy",ctrl,new_data =valid_set)
@@ -38,20 +32,20 @@
 #' m$Metrics
 #' m$modelInfo
 #' @export
-multi_model_1<-function (old_data, yname, xname, method=NULL, metric=NULL, control=NULL,new_data=NULL,  ...) 
+multi_model_1<-function (old_data, yname, xname, method=NULL, metric=NULL, control=NULL,new_data=NULL,  ...)
 {
   UseMethod("multi_model_1")
 }
 #' @export
-multi_model_1<-function (old_data, yname, xname, method=NULL, metric=NULL, control=NULL,new_data=NULL, 
+multi_model_1<-function (old_data, yname, xname, method=NULL, metric=NULL, control=NULL,new_data=NULL,
                          ...) {
-  
+
   if(any(is.null(new_data),is.null(metric),is.null(method), is.null(control))){
     stop("new_data,metric,method, and control must all be supplied")
   }
-  
 
-  
+
+
 model_formula <- as.formula(paste0(yname, "~", xname))
 fitted_model <- lapply(method, function(met) {
     set.seed(520)
@@ -62,18 +56,19 @@ fitted_model <- lapply(method, function(met) {
   predicted_values <- as.data.frame(sapply(predictions, function(x) do.call(unlist,list(x))))
   new_metric <- tolower(metric)
   names(predicted_values) <- method
- 
-  
-  
+
+
+
 metrics <- lapply(predicted_values, function(x) do.call(new_metric, list(new_data[,yname],x)))
 
-  
-final_results <- list(metric = dplyr::as_tibble(metrics), predictions = dplyr::as_tibble(predicted_values),
+
+final_results <- list(metric = as_tibble(metrics), predictions =
+                        as_tibble(predicted_values),
                       model_info=fitted_model)
- 
+
 names(final_results$metric) <- paste(names(final_results$metric),new_metric,sep = "_")
 final_results
-  
+
 
 
 }
